@@ -473,6 +473,10 @@ sub _runtime_data {
         $runtime->{'omd_cpu_perc'}  = (100-$val[7])/100;
     }
 
+    if($blocks{'DETECT VIRT'} && $blocks{'DETECT VIRT'} ne 'none') {
+        $runtime->{'virtualization_type'} = $blocks{'DETECT VIRT'};
+    }
+
     # run addons parser
     for my $mod (@{$modules}) {
         if($mod->can("extra_runtime_parse")) {
@@ -499,7 +503,7 @@ sub _ansible_available_packages {
     } elsif($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'dnf') {
         $cmd = 'dnf search omd- 2>/dev/null';
     } elsif($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'apt') {
-        $cmd = 'apt-cache search omd- 2>/dev/null';
+        $cmd = 'apt-cache search ^omd- 2>/dev/null';
     } else {
         die("unknown package manager: ".$facts->{'ansible_facts'}->{'ansible_pkg_mgr'}//'none');
     }
@@ -1071,8 +1075,10 @@ sub _remote_cmd_background_wait {
         return(1, "remote job failed to start: ".$err);
     }
 
+    my $print = Thruk::Base->verbose ? 1 : 0;
+
     # wait for $max_wait seconds
-    my $jobdata = Thruk::Utils::External::wait_for_peer_job($c, $peer, $job, 2, $max_wait, 1);
+    my $jobdata = Thruk::Utils::External::wait_for_peer_job($c, $peer, $job, 2, $max_wait, $print);
     if(!$jobdata) {
         return(1, "remote job ".$job." failed for unknown reason");
     }
@@ -1441,6 +1447,9 @@ sub get_available_omd_versions {
 ##########################################################
 sub _machine_type {
     my($facts) = @_;
+    if($facts->{'virtualization_type'}) {
+        return($facts->{'virtualization_type'});
+    }
     if($facts->{'ansible_facts'}->{'ansible_virtualization_role'} && $facts->{'ansible_facts'}->{'ansible_virtualization_role'} eq 'guest') {
         return($facts->{'ansible_facts'}->{'ansible_virtualization_type'});
     }
